# -*- coding: utf-8 -*-
"""
Predefined URLs used to make google translate requests.
"""
BASE = 'https://translate.google.cn'
TOKEN = 'https://translate.google.cn/translate_a/element.js'
TRANSLATE = 'https://translate.googleapis.com/translate_a/'
TRANSLATEURL = 'https://translate.google.cn/_/TranslateWebserverUi/data/batchexecute'

SERVICE_URLS = (
    'translate.google.ac', 'translate.google.ad', 'translate.google.ae',
    'translate.google.al', 'translate.google.am', 'translate.google.as',
    'translate.google.at', 'translate.google.az', 'translate.google.ba',
    'translate.google.be', 'translate.google.bf', 'translate.google.bg',
    'translate.google.bi', 'translate.google.bj', 'translate.google.bs',
    'translate.google.bt', 'translate.google.by', 'translate.google.ca',
    'translate.google.cat', 'translate.google.cc', 'translate.google.cd',
    'translate.google.cf', 'translate.google.cg', 'translate.google.ch',
    'translate.google.ci', 'translate.google.cl', 'translate.google.cm',
    'translate.google.cn', 'translate.google.co.ao', 'translate.google.co.bw',
    'translate.google.co.ck', 'translate.google.co.cr', 'translate.google.co.id',
    'translate.google.co.il', 'translate.google.co.in', 'translate.google.co.jp',
    'translate.google.co.ke', 'translate.google.co.kr', 'translate.google.co.ls',
    'translate.google.co.ma', 'translate.google.co.mz', 'translate.google.co.nz',
    'translate.google.co.th', 'translate.google.co.tz', 'translate.google.co.ug',
    'translate.google.co.uk', 'translate.google.co.uz', 'translate.google.co.ve',
    'translate.google.co.vi', 'translate.google.co.za', 'translate.google.co.zm',
    'translate.google.co.zw', 'translate.google.cn.af', 'translate.google.cn.ag',
    'translate.google.cn.ai', 'translate.google.cn.ar', 'translate.google.cn.au',
    'translate.google.cn.bd', 'translate.google.cn.bh', 'translate.google.cn.bn',
    'translate.google.cn.bo', 'translate.google.cn.br', 'translate.google.cn.bz',
    'translate.google.cn.co', 'translate.google.cn.cu', 'translate.google.cn.cy',
    'translate.google.cn.do', 'translate.google.cn.ec', 'translate.google.cn.eg',
    'translate.google.cn.et', 'translate.google.cn.fj', 'translate.google.cn.gh',
    'translate.google.cn.gi', 'translate.google.cn.gt', 'translate.google.cn.hk',
    'translate.google.cn.jm', 'translate.google.cn.kh', 'translate.google.cn.kw',
    'translate.google.cn.lb', 'translate.google.cn.ly', 'translate.google.cn.mm',
    'translate.google.cn.mt', 'translate.google.cn.mx', 'translate.google.cn.my',
    'translate.google.cn.na', 'translate.google.cn.ng', 'translate.google.cn.ni',
    'translate.google.cn.np', 'translate.google.cn.om', 'translate.google.cn.pa',
    'translate.google.cn.pe', 'translate.google.cn.pg', 'translate.google.cn.ph',
    'translate.google.cn.pk', 'translate.google.cn.pr', 'translate.google.cn.py',
    'translate.google.cn.qa', 'translate.google.cn.sa', 'translate.google.cn.sb',
    'translate.google.cn.sg', 'translate.google.cn.sl', 'translate.google.cn.sv',
    'translate.google.cn.tj', 'translate.google.cn.tr', 'translate.google.cn.tw',
    'translate.google.cn.ua', 'translate.google.cn.uy', 'translate.google.cn.vc',
    'translate.google.cn.vn', 'translate.google.cn', 'translate.google.cv',
    'translate.google.cz', 'translate.google.de', 'translate.google.dj',
    'translate.google.dk', 'translate.google.dm', 'translate.google.dz',
    'translate.google.ee', 'translate.google.es', 'translate.google.eu',
    'translate.google.fi', 'translate.google.fm', 'translate.google.fr',
    'translate.google.ga', 'translate.google.ge', 'translate.google.gf',
    'translate.google.gg', 'translate.google.gl', 'translate.google.gm',
    'translate.google.gp', 'translate.google.gr', 'translate.google.gy',
    'translate.google.hn', 'translate.google.hr', 'translate.google.ht',
    'translate.google.hu', 'translate.google.ie', 'translate.google.im',
    'translate.google.io', 'translate.google.iq', 'translate.google.is',
    'translate.google.it', 'translate.google.je', 'translate.google.jo',
    'translate.google.kg', 'translate.google.ki', 'translate.google.kz',
    'translate.google.la', 'translate.google.li', 'translate.google.lk',
    'translate.google.lt', 'translate.google.lu', 'translate.google.lv',
    'translate.google.md', 'translate.google.me', 'translate.google.mg',
    'translate.google.mk', 'translate.google.ml', 'translate.google.mn',
    'translate.google.ms', 'translate.google.mu', 'translate.google.mv',
    'translate.google.mw', 'translate.google.ne', 'translate.google.nf',
    'translate.google.nl', 'translate.google.no', 'translate.google.nr',
    'translate.google.nu', 'translate.google.pl', 'translate.google.pn',
    'translate.google.ps', 'translate.google.pt', 'translate.google.ro',
    'translate.google.rs', 'translate.google.ru', 'translate.google.rw',
    'translate.google.sc', 'translate.google.se', 'translate.google.sh',
    'translate.google.si', 'translate.google.sk', 'translate.google.sm',
    'translate.google.sn', 'translate.google.so', 'translate.google.sr',
    'translate.google.st', 'translate.google.td', 'translate.google.tg',
    'translate.google.tk', 'translate.google.tl', 'translate.google.tm',
    'translate.google.tn', 'translate.google.to', 'translate.google.tt',
    'translate.google.us', 'translate.google.vg', 'translate.google.vu',
    'translate.google.ws'
)