"""Free Google Translate Web API for Python. Translates totally free of charge."""
__all__ = 'Translator',
__version__ = '2.0.6'


from pygoogletranslation.translate import Translator
from pygoogletranslation.constants import LANGCODES, LANGUAGES